.. image:: https://travis-ci.org/bast/cicero.svg?branch=master
   :target: https://travis-ci.org/bast/cicero/builds
.. image:: https://img.shields.io/badge/license-%20AGPLv3-blue.svg
   :target: LICENSE
.. image:: https://img.shields.io/badge/vue-2.5.16-green.svg
   :target: https://vuejs.org


Cicero
======

Serving presentation slides written in Markdown: https://cicero.xyz

In the background uses `remark <https://github.com/gnab/remark>`__, a
simple, in-browser, markdown-driven slideshow tool created by `Ole
Petter Bang <https://github.com/gnab>`__.


Documentation
-------------

-  https://cicero.readthedocs.io


Authors
-------

-  `Radovan Bast <http://bast.fr>`__ (idea, pilot implementation, and
   plumbing)
-  `Ole Martin Bjørndalen <https://github.com/olemb>`__ (local preview
   and Blueprint solution)
-  `Roberto Di Remigio <http://totaltrash.xyz>`__ (MathJax support,
   local templating idea, slide splits)
